/*
	alt-tasks : utility for observing ALT Linux tasks
	Copyright (C) 2020 Alexey Appolonov

	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

package ar

//-----------------------------------------------------------------------------
// Types that make up the Archive type

type TaskId    uint
type SubTaskId uint
type SrcId     uint
type Timestamp uint
type HashSum   []byte

// Alt Linux task
type Task map[SubTaskId]SubTask

// Sub task that make up each ALT Linux task
type SubTask struct {
	TS     Timestamp
	Src    SrcPackage
	Commit HashSum
	}

// Src package with unique id in place of a name
type SrcPackage struct {
	// Using num ids to optimise a mem consumption and to increase a performance
	ID  SrcId
	Ver string
	Rel string
	}

// Overview-object should help to find particular elements in map of tasks
// from a specific standpoint like by a timestamp of a task, for instance
type timeOverview map[Timestamp]map[TaskId]bool
type srcOverview  map[SrcId]map[TaskId]bool
